@@ -3,7 +3,7 @@ from urllib.request import urlopen, Request
 from urllib.parse import quote_plus, unquote_plus
 from metacat.util import to_bytes, to_str
 from metacat.auth import SignedToken, SignedTokenExpiredError, SignedTokenImmatureError, TokenLib
-from metacat.webapi import MetaCatClient, MCAuthenticationError
+from metacat.webapi import MetaCatClient, AuthenticationError
 import getpass
 from metacat.ui.cli import CLI, CLICommand, InvalidOptions, InvalidArguments
 
@@ -87,7 +87,7 @@ class WhoAmICommand(CLICommand):
             user, expiration = token.subject, token.expiration
         else:
             try:    user, expiration = client.auth_info()
-            except MCAuthenticationError as e:
+            except AuthenticationError as e:
                 print(e)
         if user:
             print ("User:   ", user)
@@ -133,17 +133,21 @@ class LoginCommand(CLICommand):
             sys.exit(2)
         opts = dict(opts)
         mechanism = opts.get("-m", "password")
-        if mechanism == "password":
-            username = args[0]
-            password = getpass.getpass("Password:")
-            user, expiration = client.login_password(username, password)
-        elif mechanism == "x509":
-            cert, key = get_x509_cert_key(opts)
-            username = args[0]
-            user, expiration = client.login_x509(username, cert, key=key)
-        else:
-            print(f"Unknown authentication mechanism {mechanism}")
-            sys.exit(2)
+        try:
+            if mechanism == "password":
+                username = args[0]
+                password = getpass.getpass("Password:")
+                user, expiration = client.login_password(username, password)
+            elif mechanism == "x509":
+                cert, key = get_x509_cert_key(opts)
+                username = args[0]
+                user, expiration = client.login_x509(username, cert, key=key)
+            else:
+                print(f"Unknown authentication mechanism {mechanism}")
+                sys.exit(2)
+        except AuthenticationError:
+            print("Authentication failed")
+            sys.exit(1)
         print ("User:   ", user)
         print ("Expires:", time.ctime(expiration))
     
